@@ -75,7 +75,9 @@ def resolve_module_name(package_name: str) -> Tuple[str, Path]:
     return package_name, base_path
 
 
-def import_module_and_submodules(package_name: str, exclude: Optional[Set[str]] = None) -> None:
+def import_module_and_submodules(
+    package_name: str, exclude: Optional[Set[str]] = None, recursive: bool = True
+) -> None:
     """
     Import all submodules under the given package.
 
@@ -105,14 +107,15 @@ def import_module_and_submodules(package_name: str, exclude: Optional[Set[str]]
     path = getattr(module, "__path__", [])
     path_string = "" if not path else path[0]
 
-    # walk_packages only finds immediate children, so need to recurse.
-    for module_finder, name, _ in pkgutil.walk_packages(path):
-        # Sometimes when you import third-party libraries that are on your path,
-        # `pkgutil.walk_packages` returns those too, so we need to skip them.
-        if path_string and module_finder.path != path_string:  # type: ignore[union-attr]
-            continue
-        subpackage = f"{package_name}.{name}"
-        import_module_and_submodules(subpackage, exclude=exclude)
+    if recursive:
+        # walk_packages only finds immediate children, so need to recurse.
+        for module_finder, name, _ in pkgutil.walk_packages(path):
+            # Sometimes when you import third-party libraries that are on your path,
+            # `pkgutil.walk_packages` returns those too, so we need to skip them.
+            if path_string and module_finder.path != path_string:  # type: ignore[union-attr]
+                continue
+            subpackage = f"{package_name}.{name}"
+            import_module_and_submodules(subpackage, exclude=exclude)
 
 
 def _parse_bool(value: Union[bool, str]) -> bool:
@@ -183,6 +186,17 @@ def filename_is_safe(filename: str) -> bool:
     return all(c in SAFE_FILENAME_CHARS for c in filename)
 
 
+def make_safe_filename(name: str) -> str:
+    if filename_is_safe(name):
+        return name
+    else:
+        from tango.common.det_hash import det_hash
+
+        name_hash = det_hash(name)
+        name = name.replace(" ", "-").replace("/", "--")
+        return "".join(c for c in name if c in SAFE_FILENAME_CHARS) + f"-{name_hash[:7]}"
+
+
 def could_be_class_name(name: str) -> bool:
     if "." in name and not name.endswith("."):
         return all([_is_valid_python_name(part) for part in name.split(".")])
