@@ -43,7 +43,7 @@ from tango.step_info import GitMetadata
 from tango.version import VERSION
 from tango.workspace import Workspace
 
-from .common import Constants
+from .common import Constants, get_client
 
 logger = logging.getLogger(__name__)
 
@@ -65,9 +65,9 @@ class ResourceAssignment(NamedTuple):
     Resources assigned to a step.
     """
 
-    cluster: str
+    cluster: Union[str, List[str]]
     """
-    The cluster to use to execute the step.
+    The cluster(s) to use to execute the step.
     """
 
     resources: TaskResources
@@ -127,7 +127,6 @@ class SimpleBeakerScheduler(BeakerScheduler):
         super().__init__()
         self.clusters = clusters
         self.priority = priority
-        self._latest_clusters_used: List[str] = []
         if not self.clusters:
             raise ConfigurationError("At least one cluster is required in 'clusters'")
 
@@ -139,45 +138,10 @@ class SimpleBeakerScheduler(BeakerScheduler):
             memory=step_resources.memory,
             shared_memory=step_resources.shared_memory,
         )
-        cluster_to_use = self._ensure_cluster(task_resources)
-        if cluster_to_use is None:
-            raise ResourceAssignmentError()
-
-        # Move cluster to the end of `self._latest_clusters_used`
-        try:
-            self._latest_clusters_used.remove(cluster_to_use)  # type: ignore
-        except ValueError:
-            pass
-        self._latest_clusters_used.append(cluster_to_use)  # type: ignore
-
         return ResourceAssignment(
-            cluster=cluster_to_use, resources=task_resources, priority=self.priority
+            cluster=self.clusters, resources=task_resources, priority=self.priority
         )
 
-    def _ensure_cluster(self, task_resources: TaskResources) -> Optional[str]:
-        cluster_to_use: Optional[str] = None
-        if not self.clusters:
-            raise ConfigurationError("At least one cluster is required in 'clusters'")
-        elif len(self.clusters) == 1:
-            cluster_to_use = self.clusters[0]
-        else:
-
-            def recency_ranking(cluster_name: str):
-                try:
-                    return self._latest_clusters_used.index(cluster_name)
-                except ValueError:
-                    return -1
-
-            available_clusters = sorted(
-                self.beaker.cluster.filter_available(task_resources, *self.clusters),
-                key=lambda x: (x.queued_jobs, recency_ranking(x.cluster.full_name)),
-            )
-
-            if available_clusters:
-                cluster_to_use = available_clusters[0].cluster.full_name
-
-        return cluster_to_use
-
 
 @Executor.register("beaker")
 class BeakerExecutor(Executor):
@@ -397,7 +361,7 @@ class BeakerExecutor(Executor):
 
         super().__init__(workspace, include_package=include_package, parallelism=parallelism)
 
-        self.beaker = Beaker.from_env(default_workspace=beaker_workspace, session=True, **kwargs)
+        self.beaker = get_client(beaker_workspace=beaker_workspace, **kwargs)
         self.beaker_image = beaker_image
         self.docker_image = docker_image
         self.datasets = datasets
@@ -574,17 +538,17 @@ class BeakerExecutor(Executor):
                 ]
                 if len(waiting_for) > 5:
                     logger.info(
-                        "Waiting for %d running steps...",
+                        "Waiting for %d steps...",
                         len(waiting_for),
                     )
                 elif len(waiting_for) > 1:
                     logger.info(
-                        "Waiting for %d running steps (%s)...",
+                        "Waiting for %d steps (%s)...",
                         len(waiting_for),
-                        list(waiting_for),
+                        "'" + "', '".join(waiting_for) + "'",
                     )
                 elif len(waiting_for) == 1:
-                    logger.info("Waiting for 1 running step ('%s')...", list(waiting_for)[0])
+                    logger.info("Waiting for 1 step ('%s')...", list(waiting_for)[0])
 
                 still_to_run = [
                     step.name for step in steps_left_to_run if step.name not in submitted_steps
@@ -733,17 +697,21 @@ class BeakerExecutor(Executor):
         assert experiment is not None
         assert experiment_url is not None
 
-        # Follow the experiment and stream the logs until it completes.
+        # Follow the experiment until it completes.
         try:
             while True:
                 try:
                     self._check_if_cancelled()
                     self.beaker.experiment.wait_for(
-                        experiment, strict=True, quiet=True, timeout=2.0
+                        experiment,
+                        strict=True,
+                        quiet=True,
+                        timeout=31,
+                        poll_interval=30,
                     )
-                    time.sleep(2.0)
                     break
                 except JobTimeoutError:
+                    time.sleep(30)
                     continue
         except (JobFailedError, TaskStoppedError):
             cli_logger.error(
@@ -896,7 +864,7 @@ class BeakerExecutor(Executor):
             )
 
         # Get cluster, resources, and priority to use.
-        cluster, task_resources, priority = self.scheduler.schedule(step)
+        clusters, task_resources, priority = self.scheduler.schedule(step)
         self._check_if_cancelled()
 
         # Ensure dataset with the entrypoint script exists and get it.
@@ -941,7 +909,6 @@ class BeakerExecutor(Executor):
         task_spec = (
             TaskSpec.new(
                 step.unique_id,
-                cluster,
                 beaker_image=self.beaker_image,
                 docker_image=self.docker_image,
                 result_path=Constants.RESULTS_DIR,
@@ -952,6 +919,7 @@ class BeakerExecutor(Executor):
                 env_vars=self.env_vars,
                 priority=priority,
             )
+            .with_constraint(cluster=[clusters] if isinstance(clusters, str) else clusters)
             .with_env_var(name="TANGO_VERSION", value=VERSION)
             .with_env_var(name="GITHUB_TOKEN", secret=Constants.GITHUB_TOKEN_SECRET_NAME)
             .with_env_var(name="BEAKER_TOKEN", secret=Constants.BEAKER_TOKEN_SECRET_NAME)
